timeintervaltools.calculate_mean_attack_of_intervals
====================================================

.. autofunction:: abjad.tools.timeintervaltools.calculate_mean_attack_of_intervals.calculate_mean_attack_of_intervals
